
import sys


sys.path.append('../algorthm')

from algorthm.search.linearSearch import linearSearch


# arr = os.listdir()

# for item in arr :
#    if item.endswith(".py") and item != "__init__.py":
#       code = "from algorthm.sort."+str(item[:-3])+" import "+str(item[:-3])
#      print (code)
#     exec(code)

        
